@@ -26,8 +26,8 @@ import psycopg2.extras
 from psycopg2.extensions import connection
 from psycopg2.extras import DictCursor, NamedTupleCursor, RealDictCursor
 
-from airflow.hooks.dbapi import DbApiHook
 from airflow.models.connection import Connection
+from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 CursorType = Union[DictCursor, RealDictCursor, NamedTupleCursor]
 
@@ -137,11 +137,11 @@ class PostgresHook(DbApiHook):
                     conn.commit()
 
     def get_uri(self) -> str:
-        conn = self.get_connection(getattr(self, self.conn_name_attr))
+        """
+        Extract the URI from the connection.
+        :return: the extracted uri.
+        """
         uri = super().get_uri().replace("postgres://", "postgresql://")
-        if conn.extra_dejson.get('client_encoding', False):
-            charset = conn.extra_dejson["client_encoding"]
-            return f"{uri}?client_encoding={charset}"
         return uri
 
     def bulk_load(self, table: str, tmp_file: str) -> None:
